==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/rosterchanger.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>AddContactDialog</name>
    <message>
        <source>Please, authorize me to your presence.</source>
        <translation>Bitte authorisieren Sie mich.</translation>
    </message>
    <message>
        <source>Add contact - %1</source>
        <translation>Kontakt hinzufügen - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Chat Fenster öffnen</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Nachricht senden</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>vCard zeigen</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Resolve nick name</source>
        <translation>Spitznamen holen</translation>
    </message>
    <message>
        <source>Contact &lt;b&gt;%1&lt;/b&gt; already exists.</source>
        <translation>Kontakt &lt;b&gt;%1&lt;/b&gt; bereits vorhanden.</translation>
    </message>
    <message>
        <source>* nested group delimiter - &apos;%1&apos;</source>
        <translation>* Gruppentrennzeichen - %1</translation>
    </message>
    <message>
        <source>Can&apos;t add contact &apos;&lt;b&gt;%1&lt;/b&gt;&apos; because it is not a valid Jabber ID</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AddContactDialogClass</name>
    <message>
        <source>Nick:</source>
        <translation>Nick:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Contact:</source>
        <translation>Kontakt:</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Abo</translation>
    </message>
    <message>
        <source>Subscribe to contact presence</source>
        <translation>Kontaktpräs. abbonieren</translation>
    </message>
</context>
<context>
    <name>RosterChanger</name>
    <message>
        <source>Subscription requests</source>
        <translation>Abo Anfragen</translation>
    </message>
    <message>
        <source>%1 wants to subscribe to your presence.</source>
        <translation>%1 will Ihre Präsenz abonieren.</translation>
    </message>
    <message>
        <source>%1 unsubscribed from your presence.</source>
        <translation>%1 hat sich von Ihrer Präsenz ausgetragen.</translation>
    </message>
    <message>
        <source>You are now unsubscribed from %1 presence.</source>
        <translation>Sie Sind nun von %1 Präsenz ausgetragen</translation>
    </message>
    <message>
        <source>This group</source>
        <translation>Diese Gruppe</translation>
    </message>
    <message>
        <source>Create new...</source>
        <translation>Neue erstellen...</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Abonnement</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Request</source>
        <translation>Anfrage</translation>
    </message>
    <message>
        <source>Copy contact</source>
        <translation>Kontakt kopieren</translation>
    </message>
    <message>
        <source>Move contact</source>
        <translation>Kontakt verschieben</translation>
    </message>
    <message>
        <source>Copy group</source>
        <translation>Gruppe kopieren</translation>
    </message>
    <message>
        <source>Move group</source>
        <translation>Gruppe verschieben</translation>
    </message>
    <message>
        <source>Refuse</source>
        <translation>Abweisen</translation>
    </message>
    <message>
        <source>Copy to group</source>
        <translation>Zu Gruppe kopieren</translation>
    </message>
    <message>
        <source>Move to group</source>
        <translation>Zu Gruppe verschieben</translation>
    </message>
    <message>
        <source>Remove from group</source>
        <translation>Aus Gruppe entfernen</translation>
    </message>
    <message>
        <source>Remove from roster</source>
        <translation>vom Roster entfernen</translation>
    </message>
    <message>
        <source>Remove group</source>
        <translation>Gruppe entfernen</translation>
    </message>
    <message>
        <source>Remove contacts</source>
        <translation>Entferne Kontakte</translation>
    </message>
    <message>
        <source>Subscription message from %1</source>
        <translation>Abonnements Nachricht von %1</translation>
    </message>
    <message>
        <source>Subscription message</source>
        <translation>Abonnements Nachricht von</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Kontakt umbenennen</translation>
    </message>
    <message>
        <source>Enter name for: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Gebenen Sie einen Namen ein: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create new group</source>
        <translation>Neue Gruppe erstellen</translation>
    </message>
    <message>
        <source>Enter group name:</source>
        <translation>Gruppennamen eingeben:</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Kontakt entfernen</translation>
    </message>
    <message>
        <source>You are assured that wish to remove a contact &lt;b&gt;%1&lt;/b&gt; from roster?</source>
        <translation>Sind Sie sicher, dass sie den Kontakt &lt;b&gt;%1&lt;/b&gt; vom Roster löschen wollen?</translation>
    </message>
    <message>
        <source>Rename group</source>
        <translation>Gruppe umbenennen</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Neuen Gruppennamen eingeben:</translation>
    </message>
    <message>
        <source>You are assured that wish to remove %1 contact(s) from roster?</source>
        <translation>Sind Sie sicher, dass Sie %1 Kontakt(e) vom Roster entfernen wollen?</translation>
    </message>
    <message>
        <source>You are now subscribed for %1 presence.</source>
        <translation>Sie sind nun für %1 Präsenz eingetragen.</translation>
    </message>
    <message>
        <source>Add contact</source>
        <translation>Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Subscribe contact</source>
        <translation>Kontakt abonieren</translation>
    </message>
    <message>
        <source>Unsubscribe contact</source>
        <translation>Kontakt austragen</translation>
    </message>
    <message>
        <source>Subscribe for contact presence</source>
        <translation>Kontaktpräs. abonieren</translation>
    </message>
    <message>
        <source>You are assured that wish to subscribe for a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Sind Sie sicher, dass sie eine Kontakt &lt;b&gt;%1&lt;/b&gt; Präsenz abonieren wollen?</translation>
    </message>
    <message>
        <source>Unsubscribe from contact presence</source>
        <translation>Kontaktpräs. austragen</translation>
    </message>
    <message>
        <source>You are assured that wish to unsubscribe from a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Sind Sie sicher, dass sie sich aus einer Kontakt &lt;b&gt;%1&lt;/b&gt; Präsenz austragen wollen?</translation>
    </message>
    <message>
        <source>Roster Editor</source>
        <translation>Roster Editor</translation>
    </message>
    <message>
        <source>Allows to edit roster</source>
        <translation>Erlaubt das bearbeiten des Rosters</translation>
    </message>
    <message>
        <source>Auto accept subscription requests</source>
        <translation></translation>
    </message>
    <message>
        <source>Auto unsubscribe contacts</source>
        <translation></translation>
    </message>
    <message>
        <source>Ins</source>
        <comment>Add contact</comment>
        <translation></translation>
    </message>
    <message>
        <source>Rename contact/group</source>
        <translation></translation>
    </message>
    <message>
        <source>F2</source>
        <comment>Rename contact/group</comment>
        <translation></translation>
    </message>
    <message>
        <source>Remove contact/group from group</source>
        <translation></translation>
    </message>
    <message>
        <source>Del</source>
        <comment>Remove contact/group from group</comment>
        <translation></translation>
    </message>
    <message>
        <source>Remove contact/group from roster</source>
        <translation></translation>
    </message>
    <message>
        <source>Shift+Del</source>
        <comment>Remove contact/group from roster</comment>
        <translation></translation>
    </message>
    <message>
        <source>Add contact...</source>
        <translation></translation>
    </message>
    <message>
        <source>Blank Group</source>
        <translation></translation>
    </message>
    <message>
        <source>Roster management</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SubscriptionDialog</name>
    <message>
        <source>Subscription request - %1</source>
        <translation>Abo Anfrage - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Öffne Chat Fenster</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Nachrichts</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Sende Nachricht</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Zeige vCard</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialogClass</name>
    <message>
        <source>Add user to contact list</source>
        <translation>Füge Benutzer zur Kontaktliste hinzu</translation>
    </message>
    <message>
        <source>Authorize presence subscription</source>
        <translation>Authorisieren</translation>
    </message>
    <message>
        <source>Remove presence subscription</source>
        <translation>Authorisierung widerrufen</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/rosterchanger.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>AddContactDialog</name>
    <message>
        <source>Please, authorize me to your presence.</source>
        <translation>Bitte authorisieren Sie mich.</translation>
    </message>
    <message>
        <source>Add contact - %1</source>
        <translation>Kontakt hinzufügen - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Chat Fenster öffnen</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Nachricht senden</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>vCard zeigen</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Resolve nick name</source>
        <translation>Spitznamen holen</translation>
    </message>
    <message>
        <source>Contact &lt;b&gt;%1&lt;/b&gt; already exists.</source>
        <translation>Kontakt &lt;b&gt;%1&lt;/b&gt; bereits vorhanden.</translation>
    </message>
    <message>
        <source>* nested group delimiter - &apos;%1&apos;</source>
        <translation>* Gruppentrennzeichen - %1</translation>
    </message>
    <message>
        <source>Can&apos;t add contact &apos;&lt;b&gt;%1&lt;/b&gt;&apos; because it is not a valid Jabber ID</source>
        <translation>Kann Kontakt &apos;&lt;b&gt;%1&lt;/b&gt;&apos; nicht hinzufügen, da es keine gültige Jabber ID ist</translation>
    </message>
</context>
<context>
    <name>AddContactDialogClass</name>
    <message>
        <source>Nick:</source>
        <translation>Nick:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Contact:</source>
        <translation>Kontakt:</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Abo</translation>
    </message>
    <message>
        <source>Subscribe to contact presence</source>
        <translation>Kontaktpräs. abbonieren</translation>
    </message>
</context>
<context>
    <name>RosterChanger</name>
    <message>
        <source>%1 wants to subscribe to your presence.</source>
        <translation>%1 will Ihre Präsenz abonieren.</translation>
    </message>
    <message>
        <source>%1 unsubscribed from your presence.</source>
        <translation>%1 hat sich von Ihrer Präsenz ausgetragen.</translation>
    </message>
    <message>
        <source>You are now unsubscribed from %1 presence.</source>
        <translation>Sie Sind nun von %1 Präsenz ausgetragen.</translation>
    </message>
    <message>
        <source>This group</source>
        <translation>Diese Gruppe</translation>
    </message>
    <message>
        <source>Create new...</source>
        <translation>Neue erstellen...</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Abonnement</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Request</source>
        <translation>Anfrage</translation>
    </message>
    <message>
        <source>Copy contact</source>
        <translation>Kontakt kopieren</translation>
    </message>
    <message>
        <source>Move contact</source>
        <translation>Kontakt verschieben</translation>
    </message>
    <message>
        <source>Copy group</source>
        <translation>Gruppe kopieren</translation>
    </message>
    <message>
        <source>Move group</source>
        <translation>Gruppe verschieben</translation>
    </message>
    <message>
        <source>Refuse</source>
        <translation>Abweisen</translation>
    </message>
    <message>
        <source>Copy to group</source>
        <translation>Zu Gruppe kopieren</translation>
    </message>
    <message>
        <source>Move to group</source>
        <translation>Zu Gruppe verschieben</translation>
    </message>
    <message>
        <source>Remove from group</source>
        <translation>Aus Gruppe entfernen</translation>
    </message>
    <message>
        <source>Remove from roster</source>
        <translation>vom Roster entfernen</translation>
    </message>
    <message>
        <source>Remove group</source>
        <translation>Gruppe entfernen</translation>
    </message>
    <message>
        <source>Remove contacts</source>
        <translation>Entferne Kontakte</translation>
    </message>
    <message>
        <source>Subscription message from %1</source>
        <translation>Abonnements Nachricht von %1</translation>
    </message>
    <message>
        <source>Subscription message</source>
        <translation>Abonnements Nachricht von</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Kontakt umbenennen</translation>
    </message>
    <message>
        <source>Enter name for: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Gebenen Sie einen Namen ein: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create new group</source>
        <translation>Neue Gruppe erstellen</translation>
    </message>
    <message>
        <source>Enter group name:</source>
        <translation>Gruppennamen eingeben:</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Kontakt entfernen</translation>
    </message>
    <message>
        <source>You are assured that wish to remove a contact &lt;b&gt;%1&lt;/b&gt; from roster?</source>
        <translation>Sind Sie sicher, dass sie den Kontakt &lt;b&gt;%1&lt;/b&gt; vom Roster löschen wollen?</translation>
    </message>
    <message>
        <source>Rename group</source>
        <translation>Gruppe umbenennen</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Neuen Gruppennamen eingeben:</translation>
    </message>
    <message>
        <source>You are now subscribed for %1 presence.</source>
        <translation>Sie sind nun für %1 Präsenz eingetragen.</translation>
    </message>
    <message>
        <source>Add contact</source>
        <translation>Kontakt hinzufügen</translation>
    </message>
    <message>
        <source>Subscribe contact</source>
        <translation>Kontakt abonieren</translation>
    </message>
    <message>
        <source>Unsubscribe contact</source>
        <translation>Kontakt austragen</translation>
    </message>
    <message>
        <source>Subscribe for contact presence</source>
        <translation>Kontaktpräs. abonieren</translation>
    </message>
    <message>
        <source>You are assured that wish to subscribe for a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Sind Sie sicher, dass sie eine Kontakt &lt;b&gt;%1&lt;/b&gt; Präsenz abonieren wollen?</translation>
    </message>
    <message>
        <source>Unsubscribe from contact presence</source>
        <translation>Kontaktpräs. austragen</translation>
    </message>
    <message>
        <source>You are assured that wish to unsubscribe from a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Sind Sie sicher, dass sie sich aus einer Kontakt &lt;b&gt;%1&lt;/b&gt; Präsenz austragen wollen?</translation>
    </message>
    <message>
        <source>Roster Editor</source>
        <translation>Roster Editor</translation>
    </message>
    <message>
        <source>Allows to edit roster</source>
        <translation>Erlaubt das bearbeiten des Rosters</translation>
    </message>
    <message>
        <source>Auto accept subscription requests</source>
        <translation>Kontaktpräsenz Anfragen automatisch annehmen</translation>
    </message>
    <message>
        <source>Auto unsubscribe contacts</source>
        <translation>Kontakte automatisch austragen</translation>
    </message>
    <message>
        <source>Ins</source>
        <comment>Add contact</comment>
        <translation>Einfg</translation>
    </message>
    <message>
        <source>Rename contact/group</source>
        <translation>Kontakt/Gruppe umbenennen</translation>
    </message>
    <message>
        <source>F2</source>
        <comment>Rename contact/group</comment>
        <translation>F2</translation>
    </message>
    <message>
        <source>Remove contact/group from group</source>
        <translation>Kontakt/Gruppe aus Gruppe entfernen</translation>
    </message>
    <message>
        <source>Del</source>
        <comment>Remove contact/group from group</comment>
        <translation>Entf</translation>
    </message>
    <message>
        <source>Remove contact/group from roster</source>
        <translation>Kontakt/Gruppe aus Roster entfernen</translation>
    </message>
    <message>
        <source>Shift+Del</source>
        <comment>Remove contact/group from roster</comment>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <source>Add contact...</source>
        <translation>Kontakt Hinzufügen ...</translation>
    </message>
    <message>
        <source>Blank Group</source>
        <translation>Sonstige</translation>
    </message>
    <message>
        <source>When receiving authorization request</source>
        <translation>Wenn sie eine unauthorisierte Anfrage empfangen</translation>
    </message>
    <message numerus="yes">
        <source>You are assured that wish to remove &lt;b&gt;%n contact(s)&lt;/b&gt; from roster?</source>
        <translation>
            <numerusform>Sind sie sicher, daß sie &lt;b&gt;den Kontakt&lt;/b&gt; aus dem Roster entfernen möchten?</numerusform>
            <numerusform>Sind sie sicher, daß sie &lt;b&gt;%n Kontakte&lt;/b&gt; aus dem Roster entfernen möchten?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SubscriptionDialog</name>
    <message>
        <source>Subscription request - %1</source>
        <translation>Abo Anfrage - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Öffne Chat Fenster</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Nachrichts</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Sende Nachricht</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Zeige vCard</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialogClass</name>
    <message>
        <source>Add user to contact list</source>
        <translation>Füge Benutzer zur Kontaktliste hinzu</translation>
    </message>
    <message>
        <source>Authorize presence subscription</source>
        <translation>Authorisieren</translation>
    </message>
    <message>
        <source>Remove presence subscription</source>
        <translation>Authorisierung widerrufen</translation>
    </message>
</context>
</TS>
